summaryrefslogtreecommitdiffstats
path: root/content/common
diff options
context:
space:
mode:
authorbrianderson@chromium.org <brianderson@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-05-23 10:45:03 +0000
committerbrianderson@chromium.org <brianderson@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-05-23 10:45:03 +0000
commitc8cbae7f41a1212bce61523021a60ee78783993b (patch)
tree8a57d88602df03a587c2dcd2a95039b20ec4ef83 /content/common
parent280755cad298b37cd6ead4d16337c4e1ed79f1a0 (diff)
downloadchromium_src-c8cbae7f41a1212bce61523021a60ee78783993b.zip
chromium_src-c8cbae7f41a1212bce61523021a60ee78783993b.tar.gz
chromium_src-c8cbae7f41a1212bce61523021a60ee78783993b.tar.bz2
cc: Rename VSync to BeginFrame
We are replacing hard vsync scheduling with BeginFrame+deadline intervals. This patch removes references to vsync in CC where it will no longer make sense. (One exception is cc::VSyncTimeSource, which will be removed in future patches to be incorporated into the scheduler itself.) Additionally, BeginFrames are clarified with suffixes whenever context is not enough and existing identifiers associated with BeginFrame when it no longer makes sense are renamed. A summary of the important renames are as follows: Browser Side Renames: COutputSurface::EnableVSyncNotification -> SetNeedsBeginFrame COutputSurface::OnDidVSync -> OnBeginFrame ViewHostMsg_SetVSyncNotificationEnabled -> ViewHostMsg_SetNeedsBeginFrame ViewMsg_DidVSync -> ViewMsg_BeginFrame Impl Side Renames: LTHI::EnableVSyncNotification -> SetNeedsBeginFrame LTHI::DidVSync -> BeginFrame LTHI::DidRecieveLastInputEventForVSync -> DidReceiveLastInputEventForBeginFrame Main+Impl Side Renames: LTHIClient::DidVSync -> BeginFrameOnImplThread LTHIClient::DidRecieveLastInputEventForVSync -> DidReceiveLastInputEventForBeginFrameOnImplThread TProxy::BeginFrame -> BeginFrameOnMainThread TProxy::ForceBeginFrameOnImplThread -> ForceCommitOnImplThread TProxy::BeginFrameCompleteOnImplThread -> StartCommitOnImplThread Scheduler::BeginFrameComplete -> FinishCommit Scheduler::BeginFrameAborted -> BeginFrameAbortedByMainThread Scheduler::LastVsyncTime -> LastBeginFrameOnImplThreadTime Scheduler::VSyncTick -> BeginFrame SchedulerSM::VSyncCallbackNeeded -> BeginFrameNeededByImplThread SchedulerSM::ACTION_BEGIN_FRAME -> ACTION_SEND_BEGIN_FRAME_TO_MAIN_THREAD FRC::DidBeginFrame -> DidSwapBuffers FRC::DidFinishFrame -> DidSwapBuffersComplete Random Renames: LTSettings::render_vsync_enabled -> throttle_frame_production LTSettings::render_vsync_notification_enabled -> render_parent_drives_begin_frame LTSettings::synchronously_disable_vsync -> using_synchronous_renderer_compositor RenderWidget::SynchronouslyDisableVSync -> UsingSynchronousRendererCompositor BUG=240945 Review URL: https://chromiumcodereview.appspot.com/15058004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@201739 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/common')
-rw-r--r--content/common/view_messages.h13
1 files changed, 6 insertions, 7 deletions
diff --git a/content/common/view_messages.h b/content/common/view_messages.h
index 9eb1904..250fe37 100644
--- a/content/common/view_messages.h
+++ b/content/common/view_messages.h
@@ -1279,9 +1279,8 @@ IPC_MESSAGE_ROUTED3(ViewMsg_UpdateTopControlsState,
IPC_MESSAGE_ROUTED0(ViewMsg_ShowImeIfNeeded)
-// Sent by the browser when the display vsync signal was triggered and the
-// renderer should generate a new frame.
-IPC_MESSAGE_ROUTED1(ViewMsg_DidVSync,
+// Sent by the browser when the renderer should generate a new frame.
+IPC_MESSAGE_ROUTED1(ViewMsg_BeginFrame,
base::TimeTicks /* frame_time */)
#elif defined(OS_MACOSX)
@@ -2253,10 +2252,10 @@ IPC_MESSAGE_CONTROL3(ViewHostMsg_RunWebAudioMediaCodec,
base::FileDescriptor /* pcm_output */,
size_t /* data_size*/)
-// Sent by renderer to request a ViewMsg_VSync message for upcoming display
-// vsync events. If |enabled| is true, the vsync message will continue to be be
-// delivered until the notification is disabled.
-IPC_MESSAGE_ROUTED1(ViewHostMsg_SetVSyncNotificationEnabled,
+// Sent by renderer to request a ViewMsg_BeginFrame message for upcoming
+// display events. If |enabled| is true, the BeginFrame message will continue
+// to be be delivered until the notification is disabled.
+IPC_MESSAGE_ROUTED1(ViewHostMsg_SetNeedsBeginFrame,
bool /* enabled */)
#elif defined(OS_MACOSX)